Gothenburg by Night Gothenburg, Sweden January 12th 2002 Simon Carlsson Crypt (12 cards, min=21, max=39, avg=7.75) ------------------------------------------ 1x Etrius 11 AUS DOM OBF THA pro inner circle Tremere:2 1x Goratrix 10 ANI AUS DOM THA vic Tremere antitribu:2 1x Cardano 9 DOM FOR THA ani aus cel prince Tremere:1 1x Javier Montoya 9 AUS THA ani cel pre prince Tremere:2 1x Spiridonas 9 DOM THA pot pre prince Tremere:2 1x Ian Forestal 8 AUS DOM THA Tremere antitribu:2 1x Justine, Elder of Dallas 8 AUS DOM THA obf primogen Tremere:1 1x Kij Dansky 8 AUS DOM THA obt priscus Tremere antitribu:2 1x Muaziz, Archon of Ulugh Beg 7 THA aus dom for Tremere:2 1x Hannigan 5 AUS THA dom Tremere antitribu:2 1x Merrill Molitor 5 THA aus dom Tremere:1 1x Sarah Cobbler 4 THA dom Tremere:1 Library (90 cards) Master (15) 1x Academic Hunting Ground 1x Arcane Library 4x Blood Doll 1x Chantry 1x Dominate 1x Fame 2x Mob Connections 3x Sudden Reversal 1x Thaumaturgy Action (9) 2x Fifth Tradition: Hospitality 3x Govern the Unaligned 1x Graverobbing 2x Rutor's Hand 1x Seeds of Corruption Action Modifier (3) 3x Threats Reaction (25) 6x Deflection 4x Enhanced Senses 5x Forced Awakening 3x Precognition 3x Spirit's Touch 4x Telepathic Misdirection Combat (38) 6x Blood Fury 12x Theft of Vitae 4x Thoughts Betrayed 5x Trap 5x Walk of Flame 6x Weather Control